@@ -138,15 +138,12 @@ unsigned IsMISC (unsigned EvType)
 /******************************************************************************
  ***  IsOpenMP
  ******************************************************************************/
-#define OMP_EVENTS 53
+#define OMP_EVENTS 43
 static unsigned omp_events[] = { OMPFUNC_EV, PAR_EV, WSH_EV, BARRIEROMP_EV, 
     UNNAMEDCRIT_EV, NAMEDCRIT_EV, WORK_EV, JOIN_EV, OMPSETNUMTHREADS_EV,
-    OMPGETNUMTHREADS_EV, OMPTASKYIELD_EV, TASK_EV, TASKWAIT_EV, TASKFUNC_EV,
-    TASKFUNC_LINE_EV, OMPT_CRITICAL_EV, OMPT_ATOMIC_EV, OMPT_LOOP_EV,
-    OMPT_WORKSHARE_EV, OMPT_SECTIONS_EV, OMPT_SINGLE_EV, OMPT_MASTER_EV,
-    TASKGROUP_START_EV, TASKGROUP_END_EV, TASKID_EV, TASKLOOPID_EV,
-    OMPT_TASKGROUP_IN_EV, OMPT_DEPENDENCE_EV, OMPT_TASKFUNC_EV, OMP_STATS_EV,
-    TASKLOOP_EV, ORDERED_EV, TARGET_EV, NEW_OMP_CALL_EV, NEW_OMP_NESTED_EV,
+    OMPGETNUMTHREADS_EV, TASKYIELD_EV, TASK_EV, TASKWAIT_EV, TASKFUNC_EV,
+    TASKFUNC_LINE_EV, TASKGROUP_START_EV, TASKGROUP_END_EV, TASKID_EV, TASKLOOPID_EV,
+    OMP_STATS_EV, TASKLOOP_EV, ORDERED_EV, TARGET_EV, NEW_OMP_CALL_EV, NEW_OMP_NESTED_EV,
     NEW_OMP_PARALLEL_EV, NEW_OMP_WSH_EV, NEW_OMP_SYNC_EV, NEW_OMP_LOCK_EV,
     NEW_OMP_LOCK_NAME_EV, NEW_OMP_ORDERED_EV, NEW_OMP_TASKGROUP_EV,
     NEW_OMP_TASKING_EV, NEW_OMP_TARGET_EV, NEW_OMP_ADDRESS_EV,
@@ -209,12 +206,12 @@ unsigned IsJava (unsigned EvType)
 /******************************************************************************
  ***  IsCUDA
  ******************************************************************************/
-#define CUDA_EVENTS 9
+#define CUDA_EVENTS 10
 static unsigned cuda_events[] = {
 	/* Host events */
 	CUDACALL_EV, CUDACALLGPU_EV, CUDA_DYNAMIC_MEM_PTR_EV, CUDA_DYNAMIC_MEM_SIZE_EV,
 	CUDA_KERNEL_INST_EV, CUDA_STREAM_DEST_ID_EV, CUDA_KERNEL_EXEC_EV, CUDAEVENT_ID_EV, 
-	CUDA_UNTRACKED_EV
+	CUDA_UNTRACKED_EV, CUDA_STREAM_REGISTER_EV
 };
 
 unsigned IsCUDA (unsigned EvType)
