@@ -71,9 +71,6 @@ static char UNUSED rcsid[] = "$Id$";
 #if defined(OMP_SUPPORT) || defined(SMPSS_SUPPORT)
 # include "omp-common.h"
 # include "omp-probe.h"
-# if defined(OMPT_SUPPORT)
-#  include "ompt-wrapper.h"
-# endif /* OMPT_SUPPORT */
 #endif
 #if defined(NEW_OMP_SUPPORT)
 # include "omp_common.h"
@@ -91,6 +88,10 @@ static char UNUSED rcsid[] = "$Id$";
 # include "cuda_probe.h"
 # include "cuda_common.h"
 #endif
+#if defined(HIP_SUPPORT)
+# include "hip_probe.h"
+# include "hip_common.h"
+#endif
 #if defined(GASPI_SUPPORT)
 # include "gaspi_probe.h"
 #endif
@@ -898,7 +899,7 @@ static void Parse_XML_OMP (int rank, xmlDocPtr xmldoc, xmlNodePtr current_tag)
 		{
 #if defined(OMP_SUPPORT)
 			xmlChar *enabled = xmlGetProp_env (rank, tag, TRACE_ENABLED);
-			setTrace_OMPTaskloop ((enabled != NULL && !xmlStrcasecmp (enabled, xmlYES)));
+			setTrace_OpenMP_Taskloop ((enabled != NULL && !xmlStrcasecmp (enabled, xmlYES)));
 			XML_FREE(enabled);
 #endif
 		}
@@ -1058,6 +1059,23 @@ static void Parse_XML_CUDA (int rank, xmlNodePtr current_tag)
 }
 #endif
 
+#if defined(HIP_SUPPORT)
+/* Configure HIP related parameters */
+static void Parse_XML_HIP (int rank, xmlNodePtr current_tag)
+{
+	xmlNodePtr tag;
+
+	xmlChar *maxHipEvStr = xmlGetProp_env (rank, current_tag, TRACE_HIP_EVENTS_BUFFER_SIZE);
+	if (maxHipEvStr != NULL)
+	{
+		unsigned hi_events_block_size = atoi((char*)maxHipEvStr);
+		if(hi_events_block_size > 0)
+			XTR_HIP_SET_EVENTS_BLOCK_SIZE(hi_events_block_size);
+		mfprintf (stdout, PACKAGE_NAME": Number of allocated HIP events per block is %u \n", XTR_HIP_EVENTS_BLOCK_SIZE);
+	}
+}
+#endif
+
 /* Configure storage related parameters */
 static void Parse_XML_Storage (int rank, xmlDocPtr xmldoc, xmlNodePtr current_tag)
 {
@@ -1695,8 +1713,7 @@ static void Parse_XML_Merge (int rank, xmlDocPtr xmldoc, xmlNodePtr current_tag,
 	}
 	else
 	{
-		set_merge_OutputTraceName (filename);
-		set_merge_GivenTraceName (TRUE);
+		set_merge_OutputFileName (TRACE_FILENAME, filename);
 	}
 
 	XML_FREE (synchronization);
@@ -2049,6 +2066,26 @@ short int Parse_XML_File (int rank, int world_size, const char *filename)
 #if defined(CUDA_SUPPORT)
 						else
 							Extrae_set_trace_CUDA (FALSE);
+#endif
+						XML_FREE(enabled);
+					}
+					/* HIP related configuration */
+					else if (!xmlStrcasecmp (current_tag->name, TRACE_HIP))
+					{
+						xmlChar *enabled = xmlGetProp_env (rank, current_tag, TRACE_ENABLED);
+
+						if (enabled != NULL && !xmlStrcasecmp (enabled, xmlYES))
+						{
+#if defined(HIP_SUPPORT)
+							Extrae_set_trace_HIP (TRUE);
+							Parse_XML_HIP(rank, current_tag);
+#else
+							mfprintf (stdout, PACKAGE_NAME": Warning! <%s> tag will be ignored. This library does not support HIP.\n", TRACE_HIP);
+#endif
+						}
+#if defined(HIP_SUPPORT)
+						else
+							Extrae_set_trace_HIP (FALSE);
 #endif
 						XML_FREE(enabled);
 					}
@@ -2141,18 +2178,6 @@ short int Parse_XML_File (int rank, int world_size, const char *filename)
 #elif defined(OMP_SUPPORT) || defined(SMPSS_SUPPORT)
 							tracejant_omp = TRUE;
 							Parse_XML_OMP (rank, xmldoc, current_tag);
-
-							xmlChar *ompt = xmlGetProp_env (rank, current_tag, TRACE_OMP_OMPT);
-							if (ompt != NULL && !xmlStrcasecmp (ompt, xmlYES))
-							{
-# if defined(OMPT_SUPPORT)
-								ompt_enabled = TRUE;
-								mfprintf (stdout, PACKAGE_NAME": OMPT activated for OpenMP instrumentation.\n");
-# else
-								mfprintf (stdout, PACKAGE_NAME": Warning! <%s> tag will be ignored. This library does not support OMPT.\n", TRACE_OMP_OMPT);
-# endif /* OMPT_SUPPORT */
-							}
-							XML_FREE (ompt);
 #else
 							mfprintf (stdout, PACKAGE_NAME": Warning! <%s> tag will be ignored. This library does not support OpenMP.\n", TRACE_OMP);
 							tracejant_omp = FALSE;
